@@ -43,11 +43,9 @@ def task_ut():
 
 def task_coverage():
     """show coverage for all modules including tests"""
-    cov = Coverage([PythonPackage('doit', 'tests')],
-                   config=Config(branch=False, parallel=True,
-                                 concurrency='multiprocessing',
-                          omit=['tests/myecho.py', 'tests/sample_process.py'],)
-                   )
+    config = Config(branch=False, parallel=True, concurrency='multiprocessing',
+                    omit=['tests/myecho.py', 'tests/sample_process.py'])
+    cov = Coverage([PythonPackage('doit', 'tests')], config=config)
     yield cov.all()
     yield cov.src()
     yield cov.by_module()
@@ -134,3 +132,9 @@ def task_package():
     yield pkg.manifest_git()
     yield pkg.sdist()
     # yield pkg.sdist_upload()
+
+
+def task_codestyle():
+    return {
+        'actions': ['pycodestyle doit'],
+    }
