@@ -9,7 +9,26 @@ opt_forget_taskdep = {
     'type': bool,
     'default': False,
     'help': 'forget task dependencies too',
-    }
+}
+
+opt_disable_default = {
+    'name': 'forget_disable_default',
+    'long': 'disable-default',
+    'inverse': 'enable-default',
+    'type': bool,
+    'default': False,
+    'help': 'disable forgetting default tasks (when no arguments are passed)',
+}
+
+opt_forget_all = {
+    'name': 'forget_all',
+    'short': 'a',
+    'long': 'all',
+    'type': bool,
+    'default': False,
+    'help': 'forget all tasks',
+}
+
 
 
 class Forget(DoitCmdBase):
@@ -17,18 +36,19 @@ class Forget(DoitCmdBase):
     doc_usage = "[TASK ...]"
     doc_description = None
 
-    cmd_options = (opt_forget_taskdep, )
+    cmd_options = (opt_forget_taskdep, opt_disable_default, opt_forget_all)
 
-    def _execute(self, forget_sub):
+    def _execute(self, forget_sub, forget_disable_default, forget_all):
         """remove saved data successful runs from DB
         """
-        dependency_manager = self.dep_class(self.dep_file)
-
-        # no task specified. forget all
-        if not self.sel_tasks:
-            dependency_manager.remove_all()
+        if forget_all:
+            self.dep_manager.remove_all()
             self.outstream.write("forgetting all tasks\n")
 
+        elif self.sel_default_tasks and forget_disable_default:
+            self.outstream.write(
+                "no tasks specified, pass task name, --enable-default or --all\n")
+
         # forget tasks from list
         else:
             tasks = dict([(t.name, t) for t in self.task_list])
@@ -46,7 +66,6 @@ class Forget(DoitCmdBase):
 
             for task in to_forget:
                 # forget it - remove from dependency file
-                dependency_manager.remove(task.name)
+                self.dep_manager.remove(task.name)
                 self.outstream.write("forgetting %s\n" % task.name)
-
-        dependency_manager.close()
+        self.dep_manager.close()
