@@ -4,19 +4,19 @@ import os
 import hashlib
 import subprocess
 import inspect
+import json
 from collections import defaultdict
 from dbm import dumb
 import dbm as ddbm
 
 # uncomment imports below to run tests on all dbm backends...
-#import dumbdbm as ddbm
-#import dbm as ddbm
-#import gdbm as ddbm
+# import dumbdbm as ddbm
+# import dbm as ddbm
+# import gdbm as ddbm
 
 # note: to check which DBM backend is being used (in py2):
 #       >>> anydbm._defaultmod
 
-import json
 
 
 class DatabaseException(Exception):
@@ -47,12 +47,27 @@ def get_file_md5(path):
     return md5.hexdigest()
 
 
+class JSONCodec():
+    """default implmentation for codec used to save individual task's data"""
+    def __init__(self):
+        self.encoder = json.JSONEncoder()
+        self.decoder = json.JSONDecoder()
+
+    def encode(self, data):
+        return self.encoder.encode(data)
+
+    def decode(self, data):
+        return self.decoder.decode(data)
+
+
+
 class JsonDB(object):
     """Backend using a single text file with JSON content"""
 
-    def __init__(self, name):
+    def __init__(self, name, codec):
         """Open/create a DB file"""
         self.name = name
+        self.codec = codec
         if not os.path.exists(self.name):
             self._db = {}
         else:
@@ -63,13 +78,12 @@ class JsonDB(object):
         db_file = open(self.name, 'r')
         try:
             try:
-                return json.load(db_file)
+                return self.codec.decode(db_file.read())
             except ValueError as error:
                 # file contains corrupted json data
-                msg = (error.args[0] +
-                       "\nInvalid JSON data in %s\n" %
-                       os.path.abspath(self.name) +
-                       "To fix this problem, you can just remove the " +
+                fname = os.path.abspath(self.name)
+                msg = (f"{error.args[0]}\nInvalid JSON data in {fname}\n"
+                       "To fix this problem, you can just remove the "
                        "corrupted file, a new one will be generated.\n")
                 error.args = (msg,)
                 raise DatabaseException(msg)
@@ -80,7 +94,7 @@ class JsonDB(object):
         """save DB content in file"""
         try:
             db_file = open(self.name, 'w')
-            json.dump(self._db, db_file)
+            db_file.write(self.codec.encode(self._db))
         finally:
             db_file.close()
 
@@ -106,12 +120,12 @@ class JsonDB(object):
 
 
     def remove(self, task_id):
-        """remove saved dependecies from DB for taskId"""
+        """remove saved dependencies from DB for taskId"""
         if task_id in self._db:
             del self._db[task_id]
 
     def remove_all(self):
-        """remove saved dependecies from DB for all tasks"""
+        """remove saved dependencies from DB for all tasks"""
         self._db = {}
 
 
@@ -119,22 +133,24 @@ class JsonDB(object):
 class DbmDB(object):
     """Backend using a DBM file with individual values encoded in JSON
 
-    On initialization all items are read from DBM file and loaded on _dbm.
-    During execution whenever an item is read ('get' method) the json value
-    is cached on _db. If a item is modified _db is update and the id is added
-    to the 'dirty' set. Only on 'dump' all dirty items values are encoded
-    in json into _dbm and the DBM file is saved.
+    On initialization all items are read from DBM file and loaded on ``_dbm``.
+    During execution whenever an item is read (``get`` method) the `json` value
+    is cached on ``_db``.
+    If an item is modified ``_db`` is update and the `id` is added
+    to the `dirty` set. Only on ``dump`` all dirty items values are encoded
+    in json into ``_dbm`` and the DBM file is saved.
 
-    @ivar name: (str) file name/path
-    @ivar _dbm: (dbm) items with json encoded values
-    @ivar _db: (dict) items with python-dict as value
-    @ivar dirty: (set) id of modified tasks
+    :ivar str name: file name/path
+    :ivar dbm _dbm: items with json encoded values
+    :ivar dict _db: items with python-dict as value
+    :ivar set dirty: id of modified tasks
     """
     DBM_CONTENT_ERROR_MSG = 'db type could not be determined'
 
-    def __init__(self, name):
+    def __init__(self, name, codec):
         """Open/create a DB file"""
         self.name = name
+        self.codec = codec
         try:
             self._dbm = ddbm.open(self.name, 'c')
         except ddbm.error as exception:
@@ -159,7 +175,7 @@ class DbmDB(object):
     def dump(self):
         """save/close DBM file"""
         for task_id in self.dirty:
-            self._dbm[task_id] = json.dumps(self._db[task_id])
+            self._dbm[task_id] = self.codec.encode(self._db[task_id])
         self._dbm.close()
 
 
@@ -184,7 +200,7 @@ class DbmDB(object):
     def get(self, task_id, dependency):
         """Get value stored in the DB.
 
-        @return: (string) or (None) if entry not found
+        :return: string or None if entry not found
         """
         # optimization, just try to get it without checking it exists
         if task_id in self._db:
@@ -194,7 +210,7 @@ class DbmDB(object):
                 task_data = self._dbm[task_id]
             except KeyError:
                 return
-            self._db[task_id] = json.loads(task_data.decode('utf-8'))
+            self._db[task_id] = self.codec.decode(task_data.decode('utf-8'))
             return self._db[task_id].get(dependency, None)
 
 
@@ -204,7 +220,7 @@ class DbmDB(object):
 
 
     def remove(self, task_id):
-        """remove saved dependecies from DB for taskId"""
+        """remove saved dependencies from DB for taskId"""
         if task_id in self._db:
             del self._db[task_id]
         if self._in_dbm(task_id):
@@ -214,10 +230,10 @@ class DbmDB(object):
 
 
     def remove_all(self):
-        """remove saved dependecies from DB for all tasks"""
+        """remove saved dependencies from DB for all tasks"""
         self._db = {}
         # dumb dbm always opens file in update mode
-        if isinstance(self._dbm, dumb._Database): # pragma: no cover
+        if isinstance(self._dbm, dumb._Database):  # pragma: no cover
             self._dbm._index = {}
             self._dbm.close()
         # gdbm can not be running on 2 instances on same thread
@@ -231,14 +247,14 @@ class DbmDB(object):
 class SqliteDB(object):
     """ sqlite3 json backend """
 
-    def __init__(self, name):
+    def __init__(self, name, codec):
         self.name = name
+        self.codec = codec
         self._conn = self._sqlite3(self.name)
         self._cache = {}
         self._dirty = set()
 
-    @staticmethod
-    def _sqlite3(name):
+    def _sqlite3(self, name):
         """Open/create a sqlite3 DB file"""
 
         # Import sqlite here so it's only imported when required
@@ -250,14 +266,14 @@ class SqliteDB(object):
                 data[col[0]] = row[idx]
             return data
         def converter(data):
-            return json.loads(data.decode('utf-8'))
+            return self.codec.decode(data.decode('utf-8'))
 
-        sqlite3.register_adapter(list, json.dumps)
-        sqlite3.register_adapter(dict, json.dumps)
+        sqlite3.register_adapter(list, self.codec.encode)
+        sqlite3.register_adapter(dict, self.codec.encode)
         sqlite3.register_converter("json", converter)
         conn = sqlite3.connect(
             name,
-            detect_types=sqlite3.PARSE_DECLTYPES|sqlite3.PARSE_COLNAMES,
+            detect_types=sqlite3.PARSE_DECLTYPES | sqlite3.PARSE_COLNAMES,
             isolation_level='DEFERRED')
         conn.row_factory = dict_factory
         sqlscript = """
@@ -314,13 +330,13 @@ class SqliteDB(object):
         """save/close sqlite3 DB file"""
         for task_id in self._dirty:
             self._conn.execute('insert or replace into doit values (?,?)',
-                               (task_id, json.dumps(self._cache[task_id])))
+                               (task_id, self.codec.encode(self._cache[task_id])))
         self._conn.commit()
         self._conn.close()
         self._dirty = set()
 
     def remove(self, task_id):
-        """remove saved dependecies from DB for taskId"""
+        """remove saved dependencies from DB for taskId"""
         if task_id in self._cache:
             del self._cache[task_id]
         if task_id in self._dirty:
@@ -328,7 +344,7 @@ class SqliteDB(object):
         self._conn.execute('delete from doit where task_id=?', (task_id,))
 
     def remove_all(self):
-        """remove saved dependecies from DB for all task"""
+        """remove saved dependencies from DB for all task"""
         self._conn.execute('delete from doit')
         self._cache = {}
         self._dirty = set()
@@ -337,6 +353,14 @@ class SqliteDB(object):
 class FileChangedChecker(object):
     """Base checker for dependencies, must be inherited."""
 
+    CheckerError = os.error
+
+    def exists(self, file_path):
+        return os.path.exists(file_path)
+
+    def info(self, file_path):
+        return os.stat(file_path)
+
     def check_modified(self, file_path, file_stat, state):
         """Check if file in file_path is modified from previous "state".
 
@@ -349,7 +373,7 @@ class FileChangedChecker(object):
         raise NotImplementedError()
 
     def get_state(self, dep, current_state):
-        """Compute the state of a task after it has been successfuly executed.
+        """Compute the state of a task after it has been successfully executed.
 
         @param dep (str): path of the dependency file.
         @param current_state (tuple): the current state, saved from a previous
@@ -455,24 +479,35 @@ class DependencyStatus(object):
 
 
 class Dependency(object):
-    """Manage tasks dependencies
+    """Manage tasks dependencies.
 
-    Each dependency is saved in "db". the "db" can have json or dbm
-    format where there is a dictionary for every task. each task has a
-    dictionary where key is a dependency (abs file path), and the value is the
-    dependency signature.
-    Apart from dependencies other values are also saved on the task dictionary
-     * 'result:', 'task:<task-name>', 'ignore:'
-     * user(task) defined values are defined in '_values_:' sub-dict
+    Each dependency is saved in "db". There are several "db" backends.
+    It uses a Key-Value format where the key is task-name
+    and value is a dictionary.
+    Each task has a dictionary where keys are `dependency`'s (absolute file path),
+    and the value is the dependency signature.
+    Apart from dependencies other values are also saved on the task dictionary:
 
-    @ivar name: (string) filepath of the DB file
-    @ivar _closed: (bool) DB was flushed to file
+    * ``_values_:`` task's values
+    * ``result:`` task result
+
+    And also some internal doit attributes:
+
+    * ``ignore:``
+    * ``deps:``
+    * ``checker:``
+
+    Those can be accessed with generic DB ``get()``, see below...
+
+    :ivar string name: filepath of the DB file
+    :ivar bool _closed: DB was flushed to file
     """
-    def __init__(self, db_class, backend_name, checker_cls=MD5Checker):
+    def __init__(self, db_class, backend_name, checker_cls=MD5Checker,
+                 codec_cls=JSONCodec):
         self._closed = False
         self.checker = checker_cls()
         self.db_class = db_class
-        self.backend = db_class(backend_name)
+        self.backend = db_class(backend_name, codec=codec_cls())
         self._set = self.backend.set
         self._get = self.backend.get
         self.remove = self.backend.remove
@@ -490,9 +525,9 @@ class Dependency(object):
     ####### task specific
 
     def save_success(self, task, result_hash=None):
-        """save info after a task is successfuly executed
+        """save info after a task is successfully executed
 
-        :param result_hash: (str) explicitly set result_hash
+        :param str result_hash: explicitly set result_hash
         """
         # save task values
         self._set(task.name, "_values_:", task.values)
@@ -518,15 +553,17 @@ class Dependency(object):
 
     def get_values(self, task_name):
         """get all saved values from a task
-        @return dict
+
+        :return dict:
         """
         values = self._get(task_name, '_values_:')
         return values or {}
 
     def get_value(self, task_id, key_name):
         """get saved value from task
-        @param task_id (str)
-        @param key_name (str): key result dict of the value
+
+        :param str task_id:
+        :param str key_name: key result dict of the value
         """
         if not self._in(task_id):
             # FIXME do not use generic exception
@@ -539,7 +576,8 @@ class Dependency(object):
 
     def get_result(self, task_name):
         """get the result saved from a task
-        @return dict or md5sum
+
+        :return (dict or md5sum):
         """
         return self._get(task_name, 'result:')
 
@@ -570,7 +608,7 @@ class Dependency(object):
 
         task.dep_changed (list-strings): file-dependencies that are not
         up-to-date if task not up-to-date because of a target, returned value
-        will contain all file-dependencies reagrdless they are up-to-date
+        will contain all file-dependencies regardless they are up-to-date
         or not.
         """
         result = DependencyStatus(get_log)
@@ -598,10 +636,10 @@ class Dependency(object):
                 # 3) call it and get result
                 uptodate_result = utd(*args, **utd_kwargs)
             elif isinstance(utd, str):
-                # TODO py3.3 has subprocess.DEVNULL
-                with open(os.devnull, 'wb') as null:
-                    uptodate_result = subprocess.call(
-                        utd, shell=True, stderr=null, stdout=null) == 0
+                uptodate_result = subprocess.call(
+                    utd, shell=True,
+                    stderr=subprocess.DEVNULL,
+                    stdout=subprocess.DEVNULL) == 0
             # parameter is a value
             else:
                 uptodate_result = utd
@@ -626,7 +664,7 @@ class Dependency(object):
 
         # if target file is not there, task is not up to date
         for targ in task.targets:
-            if not os.path.exists(targ):
+            if not self.checker.exists(targ):
                 task.dep_changed = list(task.file_dep)
                 if result.add_reason('missing_target', targ):
                     return result
@@ -637,7 +675,7 @@ class Dependency(object):
         if previous and previous != checker_name:
             task.dep_changed = list(task.file_dep)
             # remove all saved values otherwise they might be re-used by
-            # some optmization on MD5Checker.get_state()
+            # some optimization on MD5Checker.get_state()
             self.remove(task.name)
             if result.set_reason('checker_changed', (previous, checker_name)):
                 return result
@@ -659,8 +697,8 @@ class Dependency(object):
         for dep in task.file_dep:
             state = self._get(task.name, dep)
             try:
-                file_stat = os.stat(dep)
-            except OSError:
+                file_stat = self.checker.info(dep)
+            except self.checker.CheckerError:
                 error_msg = "Dependent file '{}' does not exist.".format(dep)
                 result.error_reason = error_msg.format(dep)
                 if result.add_reason('missing_file_dep', dep, 'error'):
@@ -683,8 +721,8 @@ class UptodateCalculator(object):
     """Base class for 'uptodate' that need access to all tasks
     """
     def __init__(self):
-        self.get_val = None # Dependency._get
-        self.tasks_dict = None # dict with all tasks
+        self.get_val = None  # Dependency._get
+        self.tasks_dict = None  # dict with all tasks
 
     def setup(self, dep_manager, tasks_dict):
         """@param"""
