@@ -2,11 +2,11 @@ import os
 import time
 from dbm import whichdb
 
-import py
 import pytest
 
 from doit.dependency import DbmDB, Dependency, MD5Checker
 from doit.task import Task
+from doit.cmd_base import get_loader
 
 
 def get_abspath(relativePath):
@@ -19,7 +19,8 @@ def dependency_factory(relative_path):
     @pytest.fixture
     def dependency(request):
         path = get_abspath(relative_path)
-        if os.path.exists(path): os.remove(path)
+        if os.path.exists(path):  # pragma: no cover
+            os.remove(path)
         ff = open(path, "w")
         ff.write("whatever" + str(time.asctime()))
         ff.close()
@@ -41,7 +42,7 @@ dependency2 = dependency_factory("data/dependency2")
 @pytest.fixture
 def target1(request):
     path = get_abspath("data/target1")
-    if os.path.exists(path): # pragma: no cover
+    if os.path.exists(path):  # pragma: no cover
         os.remove(path)
     def remove_path():
         if os.path.exists(path):
@@ -54,38 +55,31 @@ def target1(request):
 def remove_db(filename):
     """remove db file from anydbm"""
     # dbm on some systems add '.db' on others add ('.dir', '.pag')
-    extensions = ['', #dbhash #gdbm
-                  '.bak', #dumbdb
-                  '.dat', #dumbdb
-                  '.dir', #dumbdb #dbm2
-                  '.db', #dbm1
-                  '.pag', #dbm2
-                  ]
+    extensions = [
+        '', #dbhash #gdbm
+        '.bak', #dumbdb
+        '.dat', #dumbdb
+        '.dir', #dumbdb #dbm2
+        '.db', #dbm1
+        '.pag', #dbm2
+    ]
     for ext in extensions:
         if os.path.exists(filename + ext):
             os.remove(filename + ext)
 
-# dbm backends use different file extentions
-db_ext = {'dbhash': [''],
-          'gdbm': [''],
-          'dbm': ['.db', '.dir'],
-          'dumbdbm': ['.dat'],
-          # for python3
-          'dbm.ndbm': ['.db'],
-          }
+# dbm backends use different file extensions
+db_ext = {
+    'dbhash': [''],
+    'gdbm': [''],
+    'dbm': ['.db', '.dir'],
+    'dumbdbm': ['.dat'],
+    # for python3
+    'dbm.ndbm': ['.db'],
+}
 
-@pytest.fixture
-def dep_manager(request):
-    if hasattr(request, 'param'):
-        dep_class = request.param
-    else:
-        dep_class = DbmDB
-
-    # copied from tempdir plugin
-    name = request._pyfuncitem.name
-    name = py.std.re.sub("[\W]", "_", name)
-    my_tmpdir = request.config._tmpdirhandler.mktemp(name, numbered=True)
-    dep_file = Dependency(dep_class, os.path.join(my_tmpdir.strpath, "testdb"))
+def dep_manager_fixture(request, dep_class, tmp_path_factory):
+    filename = str(tmp_path_factory.mktemp('x', True) / 'testdb')
+    dep_file = Dependency(dep_class, filename)
     dep_file.whichdb = whichdb(dep_file.name) if dep_class is DbmDB else 'XXX'
     dep_file.name_ext = db_ext.get(dep_file.whichdb, [''])
 
@@ -97,14 +91,15 @@ def dep_manager(request):
 
     return dep_file
 
-@pytest.fixture
-def depfile_name(request):
-    # copied from tempdir plugin
-    name = request._pyfuncitem.name
-    name = py.std.re.sub("[\W]", "_", name)
-    my_tmpdir = request.config._tmpdirhandler.mktemp(name, numbered=True)
-    depfile_name = (os.path.join(my_tmpdir.strpath, "testdb"))
 
+@pytest.fixture
+def dep_manager(request, tmp_path_factory):
+    return dep_manager_fixture(request, DbmDB, tmp_path_factory)
+
+
+@pytest.fixture
+def depfile_name(request, tmp_path_factory):
+    depfile_name = str(tmp_path_factory.mktemp('x', True) / 'testdb')
     def remove_depfile():
         remove_db(depfile_name)
     request.addfinalizer(remove_depfile)
@@ -125,7 +120,16 @@ def restore_cwd(request):
 def tasks_sample():
     tasks_sample = [
         # 0
-        Task("t1", [""], doc="t1 doc string"),
+        Task(
+            "t1", [""], doc="t1 doc string",
+            params=[
+                {
+                    'name': 'arg1',
+                    'short': 'a',
+                    'long': 'arg1',
+                    'default': 'default_value',
+                },
+            ]),
         # 1
         Task("t2", [""], file_dep=['tests/data/dependency1'],
              doc="t2 doc string"),
@@ -137,7 +141,7 @@ def tasks_sample():
         Task("g1.b", [""], doc="g1.b doc string", subtask_of='g1'),
         # 5
         Task("t3", [""], doc="t3 doc string", task_dep=["t1"])
-        ]
+    ]
     tasks_sample[2].task_dep = ['g1.a', 'g1.b']
     return tasks_sample
 
@@ -151,19 +155,21 @@ def tasks_bad_sample():
 
 
 def CmdFactory(cls, outstream=None, task_loader=None, dep_file=None,
-               backend=None, task_list=None, sel_tasks=None,
+               backend=None, task_list=None, sel_tasks=None, sel_default_tasks=False,
                dep_manager=None, config=None, cmds=None):
     """helper for test code, so test can call _execute() directly"""
-    cmd = cls(task_loader=task_loader, config=config, cmds=cmds)
+    loader = get_loader(config, task_loader, cmds)
+    cmd = cls(task_loader=loader, config=config, cmds=cmds)
 
     if outstream:
         cmd.outstream = outstream
     if backend:
-        assert backend == "dbm" # the only one used on tests
+        assert backend == "dbm"  # the only one used on tests
         cmd.dep_manager = Dependency(DbmDB, dep_file, MD5Checker)
     elif dep_manager:
         cmd.dep_manager = dep_manager
-    cmd.dep_file = dep_file    # (str) filename usually '.doit.db'
+    cmd.dep_file = dep_file  # (str) filename usually '.doit.db'
     cmd.task_list = task_list  # list of tasks
     cmd.sel_tasks = sel_tasks  # from command line or default_tasks
+    cmd.sel_default_tasks = sel_default_tasks
     return cmd
