@@ -3,11 +3,12 @@ import tempfile
 from io import StringIO
 from pathlib import Path, PurePath
 from sys import executable
+from collections.abc import Iterable
 
 import pytest
 
 from doit.exceptions import TaskError
-from doit.exceptions import CatchedException
+from doit.exceptions import BaseFail
 from doit import action
 from doit import task
 from doit.task import Stream
@@ -50,18 +51,21 @@ class TestStream():
 class TestTaskCheckInput(object):
 
     def testOkType(self):
-        task.Task.check_attr('xxx', 'attr', [], ([int, list],[]))
+        task.Task.check_attr('xxx', 'attr', [], ((int, list),()))
+
+    def testOkTypeABC(self):
+        task.Task.check_attr('xxx', 'attr', {}, ((Iterable,),()))
 
     def testOkValue(self):
-        task.Task.check_attr('xxx', 'attr', None, ([list], [None]))
+        task.Task.check_attr('xxx', 'attr', None, ((list,), (None,)))
 
     def testFailType(self):
         pytest.raises(task.InvalidTask, task.Task.check_attr, 'xxx',
-                      'attr', int, ([list], [False]))
+                      'attr', int, ((list,), (False,)))
 
     def testFailValue(self):
         pytest.raises(task.InvalidTask, task.Task.check_attr, 'xxx',
-                      'attr', True, ([list], [False]))
+                      'attr', True, ((list,), (False,)))
 
 
 
@@ -112,7 +116,31 @@ class TestTaskInit(object):
         assert 'p1-default' == t.options['p1']
         assert '' == t.options['p2']
         assert 'pos' == t.pos_arg
-        assert None == t.pos_arg_val # always unitialized
+        assert None == t.pos_arg_val # always uninitialized
+
+    def test_options_from_cfg(self):
+        # Ensure that doit.cfg can specify task options.
+        p1 = {'name': 'x', 'long': 'x', 'default': None}
+        t = task.Task("MyName", None, params=[p1])
+        t.cfg_values = {'x': 1}
+        assert t.options is None
+        t.init_options()
+        assert t.options is not None
+        assert 1 == t.options['x']
+
+    def test_options_from_cfg_override(self):
+        # Ensure that doit.cfg specified task options can be replaced by
+        # command line specified options.
+
+        p1 = {'name': 'x', 'long': 'x', 'default': None, 'type': int}
+        p2 = {'name': 'y', 'long': 'y', 'default': 2, 'type': int}
+        t = task.Task("MyName", None, params=[p1, p2])
+        t.cfg_values = {'x': 1}
+        assert t.options is None
+        t.init_options(['--x=2'])
+        assert t.options is not None
+        assert 2 == t.options['x']
+        assert 2 == t.options['y']
 
     def test_setup(self):
         t = task.Task("task5", ['action'], setup=["task2"])
@@ -361,7 +389,7 @@ class TestTaskTeardown(object):
         t = task.Task('t1', [], teardown=[(my_raise,)])
         t.execute(Stream(0))
         got = t.execute_teardown(Stream(0))
-        assert isinstance(got, CatchedException)
+        assert isinstance(got, BaseFail)
 
 
 class TestTaskClean(object):
@@ -370,8 +398,11 @@ class TestTaskClean(object):
     def tmpdir(self, request):
         tmpdir = {}
         tmpdir['dir'] = tempfile.mkdtemp(prefix='doit-')
+        tmpdir['subdir'] = tempfile.mkdtemp(dir=tmpdir['dir'])
         files = [os.path.join(tmpdir['dir'], fname)
-                 for fname in ['a.txt', 'b.txt']]
+                 for fname in ['a.txt',
+                               'b.txt',
+                               os.path.join(tmpdir['subdir'], 'c.txt')]]
         tmpdir['files'] = files
         # create empty files
         for filename in tmpdir['files']:
@@ -408,14 +439,15 @@ class TestTaskClean(object):
 
     def test_clean_empty_dirs(self, tmpdir):
         # Remove empty directories listed in targets
-        targets = tmpdir['files'] + [tmpdir['dir']]
+        targets = tmpdir['files'] + [tmpdir['subdir']]
         t = task.Task("xxx", None, targets=targets, clean=True)
         assert True == t._remove_targets
         assert 0 == len(t.clean_actions)
         t.clean(StringIO(), False)
         for filename in tmpdir['files']:
             assert not os.path.exists(filename)
-        assert not os.path.exists(tmpdir['dir'])
+        assert not os.path.exists(tmpdir['subdir'])
+        assert os.path.exists(tmpdir['dir'])
 
     def test_keep_non_empty_dirs(self, tmpdir):
         # Keep non empty directories listed in targets
@@ -429,6 +461,19 @@ class TestTaskClean(object):
             assert expected == os.path.exists(filename)
         assert os.path.exists(tmpdir['dir'])
 
+    def test_clean_any_order(self, tmpdir):
+        # Remove targets in reverse lexical order so that subdirectories' order
+        # in the targets array is irrelevant
+        targets = tmpdir['files'] + [tmpdir['dir'], tmpdir['subdir']]
+        t = task.Task("xxx", None, targets=targets, clean=True)
+        assert True == t._remove_targets
+        assert 0 == len(t.clean_actions)
+        t.clean(StringIO(), False)
+        for filename in tmpdir['files']:
+            assert not os.path.exists(filename)
+        assert not os.path.exists(tmpdir['dir'])
+        assert not os.path.exists(tmpdir['subdir'])
+
     def test_clean_actions(self, tmpdir):
         # a clean action can be anything, it can even not clean anything!
         c_path = tmpdir['files'][0]
@@ -611,9 +656,6 @@ class TestResultDep(object):
         # t2 result changed
         tasks['t2'].result = '222'
         dep_manager.save_success(tasks['t2'])
-
-        tasks['t1'].save_extra_values()
-        dep_manager.save_success(tasks['t1'])
         assert 'run' == dep_manager.get_status(tasks['t1'], tasks).status
 
         tasks['t1'].save_extra_values()
@@ -645,9 +687,6 @@ class TestResultDep(object):
         # t2 result changed
         tasks['t2:a'].result = '222'
         dep_manager.save_success(tasks['t2:a'])
-
-        tasks['t1'].save_extra_values()
-        dep_manager.save_success(tasks['t1'])
         assert 'run' == dep_manager.get_status(tasks['t1'], tasks).status
 
         tasks['t1'].save_extra_values()
